@@ -18,11 +18,22 @@ def run_main():
     parser.add_argument('--envname', type=str,
                         help='envname', default="CartPole-v0")
     parser.add_argument('--filepath', type=str,
-                        help='filepath', default=abs_path)
+                        help='filepath', default=abs_path + "/file.py")
+    # parser.add_argument('--filepath', type=str,
+    #                     help='filepath', default=abs_path + "/")
+    # parser.add_argument('--filepath', type=str,
+    #                     help='filepath', default= "./")
+    #
     parser.add_argument('--idiom', type=str,
                         help='idiom', default="All")
-    parser.add_argument('--outputpath', type=str,
-                        help='outputpath', default="result.json")
+    parser.add_argument('--outputdir', type=str,
+                        help='outputdir', default=abs_path + "RefactoringIdiomsOutputdir/")
+    parser.add_argument('--flag_merge_allcodepair', type=str,
+                        help='flag_merge_allcodepair', default=0)
+    parser.add_argument('--output_codepair', type=str,
+                        help='output_codepair', default="result.json")
+    parser.add_argument('--flag_console_output', type=str,
+                        help='flag_console_output', default=1)
     args = parser.parse_args()
 
 
