@@ -405,7 +405,7 @@ def get_list_compreh(content):
                 complete_new_code=ast.unparse(new_code) if remove_ass_flag else ast.unparse(assign_node) + "\n"+ast.unparse(new_code)
                 assign_node_content = ast.get_source_segment(content, assign_node)
                 for_node_content = ast.get_source_segment(content, for_node)
-                # print(">>>>>for_node_content:\n",for_node_content)
+                # print(">>>>>assign_node_content:\n",[assign_node_content, for_node_content])
                 if remove_ass_flag:
                     line_list = []
 
@@ -444,7 +444,68 @@ def get_list_compreh(content):
         code_pair_list=["syntax error in code"]
         return code_pair_list
 
+def get_list_compreh_part_fragment(content):
+    code_pair_list=[]
 
+    # print(content)
+    try:
+
+            tree = ast.parse(content)
+
+        # print("come here",ana_py.func_def_list)
+        # for tree, class_name in ana_py.func_def_list:
+            # print("come method",ast.unparse(tree))
+            try:
+                me_name=tree.name
+            except:
+                me_name=""
+            new_code_list = get_complicated_for_comprehen_code_list(tree, content)
+            # print("come method", new_code_list,ast.unparse(tree))
+            for ind, (for_node, assign_node, remove_ass_flag) in enumerate(new_code_list):
+                new_code= transform_comprehension_compli_to_simple.transform(for_node, assign_node)
+                complete_new_code=ast.unparse(new_code) if remove_ass_flag else ast.unparse(assign_node) + "\n"+ast.unparse(new_code)
+                assign_node_content = ast.get_source_segment(content, assign_node)
+                for_node_content = ast.get_source_segment(content, for_node)
+                # print(">>>>>for_node_content:\n",for_node_content)
+                if 1:
+                # if target_node_str[-1]==ast.unparse(assign_node)+"\n"+ast.unparse(for_node):
+                    if remove_ass_flag:
+                        line_list = []
+
+                        line_list.append([(assign_node.lineno,assign_node.col_offset), (assign_node.end_lineno,assign_node.end_col_offset)])
+                        line_list.append([(for_node.lineno,for_node.col_offset), (for_node.end_lineno,for_node.end_col_offset)])
+                        code_pair_list.append(['', me_name, [assign_node_content, for_node_content],
+                                               ['', ast.unparse(new_code)],
+                                               line_list])
+                        # code_pair_list.append([class_name, me_name, [ast.unparse(assign_node), ast.unparse(for_node)],
+                        #                        ['', ast.unparse(new_code)],
+                        #                        line_list])
+                    else:
+                        line_list = []
+                        line_list.append([(for_node.lineno,for_node.col_offset), (for_node.end_lineno,for_node.end_col_offset)])
+                        # code_pair_list.append(
+                        #     [class_name, me_name, [ast.unparse(for_node)], [ast.unparse(new_code)], line_list])
+                        code_pair_list.append(
+                            ['', me_name, [for_node_content], [ast.unparse(new_code)], line_list])
+
+                # if remove_ass_flag:
+                #     line_list = []
+                #     line_list.append([assign_node.lineno, assign_node.end_lineno])
+                #     line_list.append([for_node.lineno, for_node.end_lineno])
+                #     code_pair_list.append([class_name, me_name, [ast.unparse(assign_node), ast.unparse(for_node)],
+                #                            ['', ast.unparse(new_code)],
+                #                            line_list])
+                # else:
+                #     line_list = []
+                #     line_list.append([for_node.lineno, for_node.end_lineno])
+                #     code_pair_list.append([class_name,me_name,[ast.unparse(for_node)], [ast.unparse(new_code)],line_list])
+
+            return code_pair_list
+
+    except:
+        traceback.print_exc()
+        code_pair_list=["syntax error in code"]
+        return code_pair_list
 
 
 if __name__ == '__main__':
