@@ -480,12 +480,13 @@ def transform_multiple_assign_code(content):
                 # each_assign_list_str_list = [ast.unparse(e_ass) for e_ass in each_assign_list]
                 # old_node_content = ast.get_source_segment(content, old_node)
                 each_assign_list_str_list = [ ast.get_source_segment(content, e_ass) for e_ass in each_assign_list]
-
-                line_list = [[(e_ass.lineno,e_ass.col_offset), (e_ass.end_lineno,e_ass.end_col_offset)] for e_ass in each_assign_list]
                 new_code = transform_multiple_assign(each_assign_list)
 
+                new_code_list=[new_code]+[ '' for e_ass in each_assign_list[:-1]]
+                line_list = [[(e_ass.lineno,e_ass.col_offset), (e_ass.end_lineno,e_ass.end_col_offset)] for e_ass in each_assign_list]
 
-                code_pair_list.append([class_name, me_name, each_assign_list_str_list, [new_code], line_list])
+                # print("new_code_list: ",new_code_list)
+                code_pair_list.append([class_name, me_name, each_assign_list_str_list, new_code_list, line_list])
 
                 # line_list =[[e_ass.lineno, e_ass.end_lineno] for e_ass in each_assign_list]
                 # # line_list.append([[e_ass.lineno, e_ass.end_lineno] for e_ass in each_assign_list])
@@ -505,7 +506,54 @@ def transform_multiple_assign_code(content):
         traceback.print_exc()
         return code_pair_list
 
+def transform_part_multiple_assign_code(content):
+    code_pair_list = []
+    # print(content)
+    try:
 
+        tree = ast.parse(content)
+        if 1:
+            try:
+                me_name=tree.name
+            except:
+                me_name=""
+            all_assign_list, all_body_list = get_multiple_assign(tree)
+            # assign_list = split_assignments_overlap_read_write(all_assign_list, all_body_list)
+            assign_list = split_assignments(all_assign_list, all_body_list)
+            # print(">>>>>>>>>>>>>>come here: ",assign_list)
+
+
+            for ind_ass, each_assign_list in enumerate(assign_list):
+                # print(">>>>>>ind_ass: ", ind_ass)
+                each_assign_list_str = "\n".join([ast.unparse(e_ass) for e_ass in each_assign_list])
+                # each_assign_list_str_list = [ast.unparse(e_ass) for e_ass in each_assign_list]
+                # old_node_content = ast.get_source_segment(content, old_node)
+                each_assign_list_str_list = [ ast.get_source_segment(content, e_ass) for e_ass in each_assign_list]
+                new_code = transform_multiple_assign(each_assign_list)
+
+                new_code_list=[new_code]+[ '' for e_ass in each_assign_list[:-1]]
+                line_list = [[(e_ass.lineno,e_ass.col_offset), (e_ass.end_lineno,e_ass.end_col_offset)] for e_ass in each_assign_list]
+
+                # print("new_code_list: ",new_code_list)
+                code_pair_list.append(['', me_name, each_assign_list_str_list, new_code_list, line_list])
+
+                # line_list =[[e_ass.lineno, e_ass.end_lineno] for e_ass in each_assign_list]
+                # # line_list.append([[e_ass.lineno, e_ass.end_lineno] for e_ass in each_assign_list])
+                # new_code = transform_multiple_assign(each_assign_list)
+                #
+                # # new_file_content = replace_file_content_ass(content, each_assign_list, new_code)
+                # # assign_list[ind_ass].append(new_code)
+                # # complic_code_me_info_dir_pkl = util.data_root + "complic_code_me_info_dir_pkl/each_idiom_type_all_methods/multi_ass/"  # for_else
+                # # util.save_file(complic_code_me_info_dir_pkl, "test"+str(ind_ass), new_file_content, ".txt", "w")
+                # # util.save_file(complic_code_me_info_dir_pkl, "test_old"+str(ind_ass), content, ".txt", "w")
+                #
+                # code_pair_list.append([class_name,me_name,each_assign_list_str_list, [new_code],line_list])
+
+        return code_pair_list
+
+    except:
+        traceback.print_exc()
+        return code_pair_list
 def get_multiple_assign(tree):
 
     assign_list = []
